==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/EmailserverprofileRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Emailserverprofile;
import microsoft.dynamics.crm.entity.collection.request.AnnotationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.OrganizationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.TracelogCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class EmailserverprofileRequest extends EntityRequest<Emailserverprofile> {

    public EmailserverprofileRequest(ContextPath contextPath, Optional<Object> value) {
        super(Emailserverprofile.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public MailboxCollectionRequest emailserverprofile_mailbox() {
        return new MailboxCollectionRequest(
                        contextPath.addSegment("emailserverprofile_mailbox"), Optional.empty());
    }

    public MailboxRequest emailserverprofile_mailbox(String mailboxid) {
        return new MailboxRequest(contextPath.addSegment("emailserverprofile_mailbox").addKeys(new NameValue(mailboxid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest emailserverprofile_asyncoperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("emailserverprofile_asyncoperations"), Optional.empty());
    }

    public AsyncoperationRequest emailserverprofile_asyncoperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("emailserverprofile_asyncoperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public OrganizationRequest organizationid() {
        return new OrganizationRequest(contextPath.addSegment("organizationid"), Optional.empty());
    }

    public BusinessunitRequest owningbusinessunit() {
        return new BusinessunitRequest(contextPath.addSegment("owningbusinessunit"), Optional.empty());
    }

    public TeamRequest owningteam() {
        return new TeamRequest(contextPath.addSegment("owningteam"), Optional.empty());
    }

    public PrincipalRequest ownerid() {
        return new PrincipalRequest(contextPath.addSegment("ownerid"), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest emailserverprofile_bulkdeletefailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("emailserverprofile_bulkdeletefailures"), Optional.empty());
    }

    public BulkdeletefailureRequest emailserverprofile_bulkdeletefailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("emailserverprofile_bulkdeletefailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public OrganizationCollectionRequest emailServerProfile_Organization() {
        return new OrganizationCollectionRequest(
                        contextPath.addSegment("EmailServerProfile_Organization"), Optional.empty());
    }

    public OrganizationRequest emailServerProfile_Organization(String organizationid) {
        return new OrganizationRequest(contextPath.addSegment("EmailServerProfile_Organization").addKeys(new NameValue(organizationid.toString())), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public TracelogCollectionRequest tracelog_EmailServerProfile() {
        return new TracelogCollectionRequest(
                        contextPath.addSegment("tracelog_EmailServerProfile"), Optional.empty());
    }

    public TracelogRequest tracelog_EmailServerProfile(String tracelogid) {
        return new TracelogRequest(contextPath.addSegment("tracelog_EmailServerProfile").addKeys(new NameValue(tracelogid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest emailServerProfile_Annotation() {
        return new AnnotationCollectionRequest(
                        contextPath.addSegment("EmailServerProfile_Annotation"), Optional.empty());
    }

    public AnnotationRequest emailServerProfile_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("EmailServerProfile_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest emailserverprofile_duplicatematchingrecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("emailserverprofile_duplicatematchingrecord"), Optional.empty());
    }

    public DuplicaterecordRequest emailserverprofile_duplicatematchingrecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("emailserverprofile_duplicatematchingrecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest emailServerProfile_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("EmailServerProfile_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest emailServerProfile_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("EmailServerProfile_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest emailserverprofile_duplicatebaserecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("emailserverprofile_duplicatebaserecord"), Optional.empty());
    }

    public DuplicaterecordRequest emailserverprofile_duplicatebaserecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("emailserverprofile_duplicatebaserecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/request/EmailserverprofileRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Emailserverprofile;
import microsoft.dynamics.crm.entity.collection.request.AnnotationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.OrganizationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.TracelogCollectionRequest;

@JsonIgnoreType
public class EmailserverprofileRequest extends EntityRequest<Emailserverprofile> {

    public EmailserverprofileRequest(ContextPath contextPath, Optional<Object> value) {
        super(Emailserverprofile.class, contextPath, value);
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public MailboxCollectionRequest emailserverprofile_mailbox() {
        return new MailboxCollectionRequest(
                        contextPath.addSegment("emailserverprofile_mailbox"), Optional.empty());
    }

    public MailboxRequest emailserverprofile_mailbox(String mailboxid) {
        return new MailboxRequest(contextPath.addSegment("emailserverprofile_mailbox").addKeys(new NameValue(mailboxid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest emailserverprofile_asyncoperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("emailserverprofile_asyncoperations"), Optional.empty());
    }

    public AsyncoperationRequest emailserverprofile_asyncoperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("emailserverprofile_asyncoperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public OrganizationRequest organizationid() {
        return new OrganizationRequest(contextPath.addSegment("organizationid"), Optional.empty());
    }

    public BusinessunitRequest owningbusinessunit() {
        return new BusinessunitRequest(contextPath.addSegment("owningbusinessunit"), Optional.empty());
    }

    public TeamRequest owningteam() {
        return new TeamRequest(contextPath.addSegment("owningteam"), Optional.empty());
    }

    public PrincipalRequest ownerid() {
        return new PrincipalRequest(contextPath.addSegment("ownerid"), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest emailserverprofile_bulkdeletefailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("emailserverprofile_bulkdeletefailures"), Optional.empty());
    }

    public BulkdeletefailureRequest emailserverprofile_bulkdeletefailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("emailserverprofile_bulkdeletefailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public OrganizationCollectionRequest emailServerProfile_Organization() {
        return new OrganizationCollectionRequest(
                        contextPath.addSegment("EmailServerProfile_Organization"), Optional.empty());
    }

    public OrganizationRequest emailServerProfile_Organization(String organizationid) {
        return new OrganizationRequest(contextPath.addSegment("EmailServerProfile_Organization").addKeys(new NameValue(organizationid.toString())), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public TracelogCollectionRequest tracelog_EmailServerProfile() {
        return new TracelogCollectionRequest(
                        contextPath.addSegment("tracelog_EmailServerProfile"), Optional.empty());
    }

    public TracelogRequest tracelog_EmailServerProfile(String tracelogid) {
        return new TracelogRequest(contextPath.addSegment("tracelog_EmailServerProfile").addKeys(new NameValue(tracelogid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest emailServerProfile_Annotation() {
        return new AnnotationCollectionRequest(
                        contextPath.addSegment("EmailServerProfile_Annotation"), Optional.empty());
    }

    public AnnotationRequest emailServerProfile_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("EmailServerProfile_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest emailserverprofile_duplicatematchingrecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("emailserverprofile_duplicatematchingrecord"), Optional.empty());
    }

    public DuplicaterecordRequest emailserverprofile_duplicatematchingrecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("emailserverprofile_duplicatematchingrecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest emailServerProfile_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("EmailServerProfile_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest emailServerProfile_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("EmailServerProfile_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest emailserverprofile_duplicatebaserecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("emailserverprofile_duplicatebaserecord"), Optional.empty());
    }

    public DuplicaterecordRequest emailserverprofile_duplicatebaserecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("emailserverprofile_duplicatebaserecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

}
